@@ -12,7 +12,7 @@ implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU Library General Public License for more details.
 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free Software
-Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 /*
@@ -38,6 +38,8 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <builtin.h>
 #include "Integer.hP"
 
+#undef OK
+
 IntRep _ZeroRep = {1, 0, 1, {0}};
 IntRep _OneRep = {1, 0, 1, {1}};
 IntRep _MinusOneRep = {1, 0, 0, {1}};
@@ -131,7 +133,7 @@ inline static IntRep* Inew(int newlen)
   if (allocsiz >= MAXIntRep_SIZE * sizeof(short))
     (*lib_error_handler)("Integer", "Requested length out of range");
     
-  IntRep* rep = (IntRep *) new char[allocsiz];
+  IntRep* rep = new (operator new (allocsiz)) IntRep;
   rep->sz = (allocsiz - sizeof(IntRep) + sizeof(short)) / sizeof(short);
   return rep;
 }
@@ -1786,7 +1788,7 @@ IntRep* gcd(const IntRep* x, const IntRep* y)
     long s = 0;                 // shift t until odd
     cont = 1;
     int tl = t->len;
-    for (i = 0; i < tl && cont; ++i)
+    for (int i = 0; i < tl && cont; ++i)
     {
       unsigned long a = t->s[i];
       for (int j = 0; j < I_SHIFT; ++j)
@@ -2053,7 +2055,7 @@ void Integer::printon(ostream& s, int base /* =10 */, int width /* =0 */) const
   char* f = cvtItoa(x, fmtbase, fmtlen, base, showbase, width, align_right,
 		    fillchar, Xcase, showpos);
   s.write(f, fmtlen);
-  delete fmtbase;
+  delete [] fmtbase;
 }
 
 char*  cvtItoa(const IntRep* x, char* fmt, int& fmtlen, int base, int showbase,
